@@ -31,10 +31,7 @@ def _fix_filter(models, field, parts, lookup, value):
             assert False  # should have been caught above
         else:
             parts.append("raw")
-    elif field.type_ in [
-        StringChoiceArrayType,
-        NumberChoiceArrayType,
-    ]:  # pragma: postgres
+    elif field.type_ in [StringChoiceArrayType, NumberChoiceArrayType]:
         if lookup in ["contains", "not_contains"]:
             value, err = field.type_.raw_type.parse_lookup(lookup, value, None)
             choices = dict(field.choices)
@@ -49,10 +46,13 @@ def _fix_filter(models, field, parts, lookup, value):
 
 
 def forwards_0009(View):
+    from data_browser.views import _add_request_info
+
     User = get_user_model()
 
     request = RequestFactory().get(reverse("admin:index"))
     request.user = User(is_superuser=True)
+    _add_request_info(request)
     models = get_models(request)
 
     for view in View.objects.all():
