@@ -12,7 +12,7 @@ from data_browser.query import BoundQuery, Query
 
 from .conftest import POSTGRES
 from .core import models
-from .util import ANY, KEYS
+from .util import ANY, KEYS, UTC
 
 
 def sortedAssert(a, b):
@@ -77,16 +77,16 @@ def pivot_products(db):
     address = models.Address.objects.create(city="london", street="bad")
     producer = models.Producer.objects.create(name="Bob", address=address)
     datetimes = [
-        datetime(2020, 1, 1, tzinfo=timezone.utc),
-        datetime(2020, 2, 1, tzinfo=timezone.utc),
-        datetime(2020, 2, 2, tzinfo=timezone.utc),
-        datetime(2021, 1, 1, tzinfo=timezone.utc),
-        datetime(2021, 1, 2, tzinfo=timezone.utc),
-        datetime(2021, 1, 3, tzinfo=timezone.utc),
-        datetime(2021, 2, 1, tzinfo=timezone.utc),
-        datetime(2021, 2, 2, tzinfo=timezone.utc),
-        datetime(2021, 2, 3, tzinfo=timezone.utc),
-        datetime(2021, 2, 4, tzinfo=timezone.utc),
+        datetime(2020, 1, 1, tzinfo=UTC),
+        datetime(2020, 2, 1, tzinfo=UTC),
+        datetime(2020, 2, 2, tzinfo=UTC),
+        datetime(2021, 1, 1, tzinfo=UTC),
+        datetime(2021, 1, 2, tzinfo=UTC),
+        datetime(2021, 1, 3, tzinfo=UTC),
+        datetime(2021, 2, 1, tzinfo=UTC),
+        datetime(2021, 2, 2, tzinfo=UTC),
+        datetime(2021, 2, 3, tzinfo=UTC),
+        datetime(2021, 2, 4, tzinfo=UTC),
     ]
     for i, dt in enumerate(datetimes):
         models.Product.objects.create(
@@ -186,6 +186,7 @@ def test_get_url_link(get_product_flat):
     sortedAssert(data, [["a", None], ["b", "www.google.com"]])
 
 
+@pytest.mark.skipif(django.VERSION > (4, 2), reason="Unable to reproduce on 4.2")
 def test_bad_storage(monkeypatch, admin_ddb_request):
     # break storage
     from django.core.files.storage import FileSystemStorage, default_storage
@@ -241,7 +242,6 @@ def test_get_annotated_field_at_base(
     assert len(mock_admin_get_queryset.call_args_list) == 6  # 4 for setup, 2 for query
 
 
-@pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
 def test_get_aggretated_annotated_field_at_base(
     products, get_product_flat, mock_admin_get_queryset
 ):
@@ -250,7 +250,6 @@ def test_get_aggretated_annotated_field_at_base(
     assert len(mock_admin_get_queryset.call_args_list) == 6  # 4 for setup, 2 for query
 
 
-@pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
 def test_filter_and_select_aggregated_annotation(products, get_product_flat):
     data = get_product_flat(
         1, "annotated__count+1,size", [("annotated__count__gt", "1")]
@@ -258,7 +257,6 @@ def test_filter_and_select_aggregated_annotation(products, get_product_flat):
     assert data == [[1, 2]]  # aggregates last
 
 
-@pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
 def test_filter_and_select_annotation_function(products, get_product_flat):
     data = get_product_flat(
         1, "annotated__is_null+1,size", [("annotated__is_null__equals", "NotNull")]
@@ -286,7 +284,6 @@ def test_get_annotated_field_down_tree(
     assert len(mock_admin_get_queryset.call_args_list) == 6  # 4 for setup, 2 for query
 
 
-@pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
 def test_get_aggregated_annotated_field_down_tree(
     products, get_product_flat, mock_admin_get_queryset
 ):
@@ -577,8 +574,6 @@ def test_get_results_one_to_one(get_product_flat):
 
 @pytest.mark.usefixtures("products")
 def test_get_results_many_to_one(get_product_flat, mocker):
-    mocker.patch("data_browser.orm_admin.get_feature_flag", return_value=True)
-
     data = get_product_flat(1, "name+0,producer__products__name+1", [])
     assert data == [["a", "a"], ["b", "b"], ["c", "c"]]
 
@@ -650,12 +645,12 @@ def test_pivot_sorting_with_empty_cell(get_product_pivot):
     producer = models.Producer.objects.create(name="Bob", address=address)
     datetimes = [
         # 2021, 1, 1 is notably missing
-        datetime(2021, 2, 1, tzinfo=timezone.utc),
-        datetime(2022, 1, 1, tzinfo=timezone.utc),
-        datetime(2022, 1, 2, tzinfo=timezone.utc),
-        datetime(2022, 2, 1, tzinfo=timezone.utc),
-        datetime(2022, 2, 2, tzinfo=timezone.utc),
-        datetime(2022, 2, 3, tzinfo=timezone.utc),
+        datetime(2021, 2, 1, tzinfo=UTC),
+        datetime(2022, 1, 1, tzinfo=UTC),
+        datetime(2022, 1, 2, tzinfo=UTC),
+        datetime(2022, 2, 1, tzinfo=UTC),
+        datetime(2022, 2, 2, tzinfo=UTC),
+        datetime(2022, 2, 3, tzinfo=UTC),
     ]
     for dt in datetimes:
         models.Product.objects.create(created_time=dt, name=str(dt), producer=producer)
@@ -683,17 +678,17 @@ def test_pivot_sorting_body(get_product_pivot):
     address = models.Address.objects.create(city="london", street="bad")
     producer = models.Producer.objects.create(name="Bob", address=address)
     datetimes = [
-        datetime(2021, 1, 1, tzinfo=timezone.utc),
-        datetime(2021, 2, 1, tzinfo=timezone.utc),
-        datetime(2021, 2, 2, tzinfo=timezone.utc),
-        datetime(2021, 2, 3, tzinfo=timezone.utc),
-        datetime(2022, 1, 1, tzinfo=timezone.utc),
-        datetime(2022, 1, 2, tzinfo=timezone.utc),
-        datetime(2022, 1, 3, tzinfo=timezone.utc),
-        datetime(2022, 1, 4, tzinfo=timezone.utc),
-        datetime(2022, 2, 1, tzinfo=timezone.utc),
-        datetime(2022, 2, 2, tzinfo=timezone.utc),
-        datetime(2022, 2, 3, tzinfo=timezone.utc),
+        datetime(2021, 1, 1, tzinfo=UTC),
+        datetime(2021, 2, 1, tzinfo=UTC),
+        datetime(2021, 2, 2, tzinfo=UTC),
+        datetime(2021, 2, 3, tzinfo=UTC),
+        datetime(2022, 1, 1, tzinfo=UTC),
+        datetime(2022, 1, 2, tzinfo=UTC),
+        datetime(2022, 1, 3, tzinfo=UTC),
+        datetime(2022, 1, 4, tzinfo=UTC),
+        datetime(2022, 2, 1, tzinfo=UTC),
+        datetime(2022, 2, 2, tzinfo=UTC),
+        datetime(2022, 2, 3, tzinfo=UTC),
     ]
     for dt in datetimes:
         models.Product.objects.create(created_time=dt, name=str(dt), producer=producer)
@@ -780,9 +775,6 @@ def test_get_fields(orm_models):
     assert "pk" not in orm_models["core.Product"].fields
     assert "id" in orm_models["core.Product"].fields
 
-    # no many to many fields
-    assert "tags" not in orm_models["core.Product"].fields
-
     # no admin on inlines
     assert "admin" not in orm_models["core.InlineAdmin"].fields
 
@@ -804,10 +796,14 @@ class TestPermissions:
 
         assert "core.NotInAdmin" not in orm_models
         assert orm_models["core.InAdmin"] == OrmModel(
-            fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin), pk="id"
+            fields=KEYS("admin", "id", "name", "normal", "inlineadmin"),
+            admin=ANY(BaseModelAdmin),
+            pk="id",
         )
         assert orm_models["core.InlineAdmin"] == OrmModel(
-            fields=KEYS("id", "name", "in_admin"), admin=ANY(BaseModelAdmin), pk="id"
+            fields=KEYS("id", "name", "in_admin", "normal"),
+            admin=ANY(BaseModelAdmin),
+            pk="id",
         )
         assert orm_models["core.Normal"] == OrmModel(
             fields=KEYS(
@@ -853,7 +849,9 @@ class TestPermissions:
 
         assert "core.NotInAdmin" not in orm_models
         assert orm_models["core.InAdmin"] == OrmModel(
-            fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin), pk="id"
+            fields=KEYS("admin", "id", "name", "normal"),
+            admin=ANY(BaseModelAdmin),
+            pk="id",
         )
         assert "core.InlineAdmin" not in orm_models
         assert orm_models["core.Normal"] == OrmModel(
@@ -885,7 +883,7 @@ class TestPermissions:
 def test_all_datetime_functions(get_product_flat, lookup, value):
     models.Product.objects.create(
         producer=models.Producer.objects.create(),
-        created_time=datetime(2020, 1, 2, 3, 4, 5, 6, tzinfo=timezone.utc),
+        created_time=datetime(2020, 1, 2, 3, 4, 5, 6, tzinfo=UTC),
     )
 
     fields = f"created_time__{lookup}" if lookup else "created_time"
@@ -893,7 +891,6 @@ def test_all_datetime_functions(get_product_flat, lookup, value):
     assert data == [[value]]
 
 
-@pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
 @pytest.mark.django_db
 @pytest.mark.parametrize(
     "lookup,value", [("iso_year", 2020), ("iso_week", 1), ("week_start", "2019-12-30")]
@@ -901,7 +898,7 @@ def test_all_datetime_functions(get_product_flat, lookup, value):
 def test_all_datetime_functions_2_2(get_product_flat, lookup, value):
     models.Product.objects.create(
         producer=models.Producer.objects.create(),
-        created_time=datetime(2020, 1, 2, 3, 4, 5, 6, tzinfo=timezone.utc),
+        created_time=datetime(2020, 1, 2, 3, 4, 5, 6, tzinfo=UTC),
     )
 
     fields = f"created_time__{lookup}" if lookup else "created_time"
@@ -917,16 +914,16 @@ def test_all_datetime_functions_2_2(get_product_flat, lookup, value):
 def test_datetime_aggregations(get_product_flat, aggregation, value):
     producer = models.Producer.objects.create()
     models.Product.objects.create(
-        producer=producer, created_time=datetime(2020, 1, 1, tzinfo=timezone.utc)
+        producer=producer, created_time=datetime(2020, 1, 1, tzinfo=UTC)
     )
     models.Product.objects.create(
-        producer=producer, created_time=datetime(2020, 1, 2, tzinfo=timezone.utc)
+        producer=producer, created_time=datetime(2020, 1, 2, tzinfo=UTC)
     )
     models.Product.objects.create(
-        producer=producer, created_time=datetime(2020, 1, 2, tzinfo=timezone.utc)
+        producer=producer, created_time=datetime(2020, 1, 2, tzinfo=UTC)
     )
     models.Product.objects.create(
-        producer=producer, created_time=datetime(2020, 1, 3, tzinfo=timezone.utc)
+        producer=producer, created_time=datetime(2020, 1, 3, tzinfo=UTC)
     )
 
     data = get_product_flat(1, f"created_time__{aggregation}", [])
