@@ -2,15 +2,14 @@ import csv
 import json
 from datetime import datetime
 
-import django
 import pytest
 from django.contrib.auth.models import User
-from django.utils import timezone
 
 import data_browser.models
 
 from .conftest import SQLITE
 from .core import models
+from .util import UTC
 
 
 def dump(val):
@@ -31,12 +30,12 @@ def pivot_products(db):
     address = models.Address.objects.create(city="london", street="bad")
     producer = models.Producer.objects.create(name="Bob", address=address)
     datetimes = [
-        datetime(2020, 1, 1, tzinfo=timezone.utc),
-        datetime(2020, 2, 1, tzinfo=timezone.utc),
-        datetime(2020, 2, 2, tzinfo=timezone.utc),
-        datetime(2021, 1, 1, tzinfo=timezone.utc),
-        datetime(2021, 1, 2, tzinfo=timezone.utc),
-        datetime(2021, 1, 3, tzinfo=timezone.utc),
+        datetime(2020, 1, 1, tzinfo=UTC),
+        datetime(2020, 2, 1, tzinfo=UTC),
+        datetime(2020, 2, 2, tzinfo=UTC),
+        datetime(2021, 1, 1, tzinfo=UTC),
+        datetime(2021, 1, 2, tzinfo=UTC),
+        datetime(2021, 1, 3, tzinfo=UTC),
     ]
     for i, dt in enumerate(datetimes):
         models.Product.objects.create(
@@ -44,7 +43,6 @@ def pivot_products(db):
         )
 
 
-@pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
 def test_query_html(admin_client, snapshot):
     res = admin_client.get(
         "/data_browser/query/core.Product/size-0,name+1,size_unit.html"
@@ -77,7 +75,6 @@ def test_query_misc_formats(admin_client, format):
     assert res.status_code == 200
 
 
-@pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
 def test_query_explain(admin_client):
     res = admin_client.get(
         "/data_browser/query/core.Product/size-0,name+1,size_unit.explain"
@@ -110,7 +107,6 @@ def test_query_bad_formats(admin_client, format):
     assert res.status_code == 404
 
 
-@pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
 def test_query_html_no_perms(admin_user, admin_client, snapshot):
     admin_user.is_superuser = False
     admin_user.save()
@@ -121,7 +117,6 @@ def test_query_html_no_perms(admin_user, admin_client, snapshot):
         snapshot.assert_match(config, "config")
 
 
-@pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
 def test_query_ctx(admin_client, snapshot):
     res = admin_client.get("/data_browser/query//.ctx?")
     assert res.status_code == 200
@@ -130,9 +125,7 @@ def test_query_ctx(admin_client, snapshot):
         snapshot.assert_match(config, "config")
 
 
-@pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
 def test_query_ctx_m2m(admin_client, snapshot, mocker):
-    mocker.patch("data_browser.orm_admin.get_feature_flag", return_value=True)
     res = admin_client.get("/data_browser/query//.ctx?")
     assert res.status_code == 200
     config = res.json()
@@ -471,6 +464,36 @@ def test_action_filtered(admin_client):
     assert set(res.context[0]["queryset"].values_list("id", flat=True)) == {id_}
 
 
+@pytest.mark.usefixtures("products")
+def test_action_sorted_and_limited(admin_client):
+    url = "/data_browser/query/core.Product/id%s0.%s?limit=1"
+
+    ids = set(models.Product.objects.values_list("id", flat=True))
+
+    for direction, id_ in [("+", min(ids)), ("-", max(ids))]:
+        # check our view is right
+        res = admin_client.get(url % (direction, "json"))
+        assert {row["id"] for row in res.json()["rows"]} == {id_}
+
+        # ask data browser for the action request
+        res = admin_client.post(
+            url % (direction, "html"),
+            {"action": "delete_selected", "field": "id"},
+            content_type="application/json",
+        ).json()
+        assert res == {
+            "method": "post",
+            "url": "/admin/core/product/?",
+            "data": [
+                ["action", "delete_selected"],
+                ["select_across", 0],
+                ["index", 0],
+                ["data_browser", 1],
+                ["_selected_action", id_],
+            ],
+        }
+
+
 @pytest.mark.usefixtures("products")
 def test_related_action(admin_client):
     url = "/data_browser/query/core.Product/address__id,producer__id,id.%s"
